@@ -14,7 +14,10 @@ sub match {
     my $class = shift;
     my $argv1 = shift // return undef;
 
-    state $index = ['message too large'];
+    state $index = [
+        'message header size exceeds limit',
+        'message too large',
+    ];
     return 1 if grep { rindex($argv1, $_) > -1 } @$index;
     return 0;
 }
@@ -103,7 +106,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018,2021 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
