@@ -20,6 +20,7 @@ sub match {
         'host does not accept mail',        # Sendmail
         'name server: .: host not found',   # Sendmail
         'no mx record found for domain=',   # Oath(Yahoo!)
+        'no route for current request',
         'smtp protocol returned a permanent error',
     ];
     return 1 if grep { rindex($argv1, $_) > -1 } @$index;
@@ -39,7 +40,7 @@ sub true {
 
     # SMTP Reply Code is 521, 554 or 556
     return 1 if $argvs->replycode =~ /\A(?:521|554|556)\z/;
-    return 0 unless $argvs->smtpcommand eq 'MAIL';
+    return 0 if $argvs->smtpcommand ne 'MAIL';
     return 1 if __PACKAGE__->match(lc $argvs->diagnosticcode);
     return 0;
 }
@@ -93,7 +94,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016,2018,2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018,2020,2021 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
