@@ -20,8 +20,8 @@ sub match {
         'sender ip address rejected',
     ];
     state $index = [
-        '<> invalid sender',
         'access denied (in reply to mail from command)',
+        'access denied (sender blacklisted)',
         'address rejected',
         'administrative prohibition',
         'batv failed to verify',    # SoniWall
@@ -30,6 +30,7 @@ sub match {
         'bogus mail from',          # IMail - block empty sender
         'connections not accepted from servers without a valid sender domain',
         'denied [bouncedeny]',      # McAfee
+        'denied by secumail valid-address-filter',
         'delivery not authorized, message refused',
         'does not exist e2110',
         'domain of sender address ',
@@ -40,6 +41,7 @@ sub match {
         'from: domain is invalid. please provide a valid from:',
         'fully qualified email address required',   # McAfee
         'invalid domain, see <url:',
+        'invalid sender',
         'is not a registered gateway user',
         'mail from not owned by user',
         'message rejected: email address is not verified',
@@ -50,6 +52,7 @@ sub match {
         'returned mail not accepted here',
         'rfc 1035 violation: recursive cname records for',
         'rule imposed mailbox access for',  # MailMarshal
+        'sender address has been blacklisted',
         'sender email address rejected',
         'sender is spammer',
         'sender not pre-approved',
@@ -58,6 +61,7 @@ sub match {
         'sender verify failed', # Exim callout
         'syntax error: empty email address',
         'the message has been rejected by batv defense',
+        'this server does not accept mail from',
         'transaction failed unsigned dsn for',
         'unroutable sender address',
         'you are sending to/from an address that has been blacklisted',
@@ -155,7 +159,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2019 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2019,2021 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
