@@ -157,6 +157,11 @@ sub true {
     return undef unless $argvs->deliverystatus;
     return 1 if $argvs->reason eq 'spamdetected';
     return 1 if (Sisimai::SMTP::Status->name($argvs->deliverystatus) || '') eq 'spamdetected';
+
+    # The value of "reason" isn't "spamdetected" when the value of "smtpcommand" is an SMTP command
+    # to be sent before the SMTP DATA command because all the MTAs read the headers and the entire
+    # message body after the DATA command.
+    return 0 if $argvs->{'smtpcommand'} =~ /\A(?:CONN|EHLO|HELO|MAIL|RCPT)\z/;
     return 1 if __PACKAGE__->match(lc $argvs->diagnosticcode);
     return 0;
 }
